Skip to contents

attendance() retrieves the attendance by season and game type as a data.frame where each row represents season and includes detail on date/season filtering windows and chronological context.

Usage

attendance()

Value

data.frame with one row per season

Examples

all_attendance <- attendance()