boxscore: Access the boxscore for a game, team, and position

View source: R/Game.R

boxscoreR Documentation

Access the boxscore for a game, team, and position

Description

boxscore() returns one side of the GameCenter boxscore for one position group. Each row is a player with normalized name/position fields and the game-stat columns exposed for that group.

Usage

boxscore(game = 2023030417, team = "home", position = "forwards")

Arguments

game

integer ID (e.g., 2025020275); see games() for reference

team

character of 'h'/'home' or 'a'/'away'

position

character of 'f'/'forwards', 'd'/'defensemen', or 'g'/'goalies'

Value

data.frame with one row per player

Examples

boxscore_COL_forwards_Martin_Necas_legacy_game <- boxscore(
  game     = 2025020275,
  team     = 'H',
  position = 'F'
)

nhlscraper documentation built on June 29, 2026, 1:06 a.m.