calculate_distance: Calculate the Euclidean distance from the attacking net for all the events (plays) in a play-by-play
Description
calculate_distance() calculates the Euclidean distance from the attacking net for all the events (plays) in a play-by-play.
Usage
calculate_distance(play_by_play)
Value
data.frame with one row per event (play) and added distance column
Arguments
- play_by_play
data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference