coach_franchise_statistics: Access the statistics for all the coaches by franchise and...

View source: R/Coach.R

coach_franchise_statisticsR Documentation

Access the statistics for all the coaches by franchise and game type

Description

coach_franchise_statistics() returns coach records by franchise and game type, with one row per coach/franchise/game-type stint.

Usage

coach_franchise_statistics()

coach_franchise_stats()

Value

data.frame with one row per franchise per coach per game type

Examples

coach_franchise_stats <- coach_franchise_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.