Skip to contents

coaches() retrieves all the coaches as a data.frame where each row represents coach and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.

Usage

coaches()

Value

data.frame with one row per coach

Examples

all_coaches <- coaches()