Skip to contents

combine_reports() retrieves the draft combine reports as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile.

Usage

combine_reports()

Value

data.frame with one row per player

Examples

combine_reports <- combine_reports()