Learn R Programming

nhlscraper (version 0.5.0)

countries: Access all the countries

Description

countries() retrieves all the countries as a data.frame where each row represents country and includes detail on reference metadata, regional context, and media availability detail.

Usage

countries()

Arguments

Value

data.frame with one row per country

Examples

Run this code
all_countries <- countries()

Run the code above in your browser using DataLab