dot-calculate_angle: Calculate the Euclidean angle from the attacking net for all...

.calculate_angleR Documentation

Calculate the Euclidean angle from the attacking net for all the events (plays) in a play-by-play

Description

.calculate_angle() calculates the Euclidean angle from the attacking net for all the events (plays) in a play-by-play.

Usage

.calculate_angle(play_by_play)

Arguments

play_by_play

data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference

Value

data.frame with one row per event (play) and added angle column


nhlscraper documentation built on June 29, 2026, 1:06 a.m.