dot-compute_pbp_deltas: Compute play-by-play deltas with native fallback

.compute_pbp_deltasR Documentation

Compute play-by-play deltas with native fallback

Description

.compute_pbp_deltas() validates the public schema, then uses the native delta routine when available and falls back to R otherwise.

Usage

.compute_pbp_deltas(play_by_play)

Arguments

play_by_play

data.frame of play-by-play(s) using the current public schema returned by gc_play_by_play(), gc_play_by_plays(), wsc_play_by_play(), or wsc_play_by_plays()

Value

named list containing delta context vectors


nhlscraper documentation built on June 29, 2026, 1:06 a.m.