dot-ensure_local_native_symbol: Ensure a native symbol is available

.ensure_local_native_symbolR Documentation

Ensure a native symbol is available

Description

.ensure_local_native_symbol() checks whether a native symbol is already registered and, if needed, tries to load the installed package shared object. It does not trust the current working directory.

Usage

.ensure_local_native_symbol(symbol)

Arguments

symbol

native symbol name

Value

logical scalar indicating whether the symbol is available


nhlscraper documentation built on June 29, 2026, 1:06 a.m.