| .flag_is_rebound | R Documentation |
.flag_is_rebound() flags whether a shot attempt is a rebound attempt (i.e., taken within 3 seconds of a prior blocked, missed, or saved attempt with no stoppage in between), and whether a shot attempt creates a rebound under the same definition.
.flag_is_rebound(play_by_play)
play_by_play |
data.frame of play-by-play(s); see |
data.frame with one row per event (play) and added columns: createdRebound and isRebound
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.