dot-nhl_request: Build an NHL API request

.nhl_requestR Documentation

Build an NHL API request

Description

.nhl_request() selects the requested NHL API host and constructs a retrying request object. It is used by public wrappers that need to fetch requests in parallel before parsing the body.

Usage

.nhl_request(path, query = list(), type)

Arguments

path

character

query

list

type

character of 'w' for web, 's' for stats, and 'r' for records

Value

httr2 request object


nhlscraper documentation built on June 29, 2026, 1:06 a.m.