| .require_public_pbp_columns | R Documentation |
.require_public_pbp_columns() errors when a public helper is called with a
play-by-play missing required public schema columns.
.require_public_pbp_columns(play_by_play, cols, fn_name)
play_by_play |
data.frame play-by-play object |
cols |
character vector of required columns |
fn_name |
calling function name used in the error message |
NULL, invisibly, or an error if required columns are missing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.