dot-require_shift_chart_columns: Validate required shift-chart columns

.require_shift_chart_columnsR Documentation

Validate required shift-chart columns

Description

.require_shift_chart_columns() errors when a helper is called with a shift chart missing required public schema columns.

Usage

.require_shift_chart_columns(shift_chart, cols, fn_name)

Arguments

shift_chart

data.frame shift chart object

cols

character vector of required columns

fn_name

calling function name used in the error message

Value

NULL, invisibly, or an error if required columns are missing


nhlscraper documentation built on June 29, 2026, 1:06 a.m.