dot-strip_time_period: Strip the timestamp and period number into the time elapsed...

.strip_time_periodR Documentation

Strip the timestamp and period number into the time elapsed in the period and game for all the events (plays) in a play-by-play

Description

.strip_time_period() strips the timestamp and period number into the time elapsed in the period and game for all the events (plays) in a play-by-play.

Usage

.strip_time_period(play_by_play)

Arguments

play_by_play

data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference

Value

data.frame with one row per event (play) and added columns secondsElapsedInPeriod and secondsElapsedInGame


nhlscraper documentation built on June 29, 2026, 1:06 a.m.