Learn R Programming

nhlscraper (version 0.5.0)

draft_prospects: Access all the draft prospects

Description

draft_prospects() retrieves all the draft prospects as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile plus broadcast carriage, media availability, and viewing-link metadata.

Usage

draft_prospects()

Arguments

Value

data.frame with one row per player

Examples

Run this code
# May take >5s, so skip.
all_prospects <- draft_prospects()

Run the code above in your browser using DataLab