Skip to contents

espn_injuries() returns ESPN's current injury report with one outer row per team and nested player injury details where ESPN includes them.

Usage

espn_injuries()

Value

nested data.frame with one row per team (outer) and player (inner)

Examples

ESPN_injuries_now <- espn_injuries()