espn_player_summary() returns a compact one-row ESPN athlete profile with
name, birth, size, handedness, draft, debut, position, experience, and active
status fields.
Arguments
- player
integer ID (e.g., 3988803); see
espn_players()for reference
espn_player_summary() returns a compact one-row ESPN athlete profile with
name, birth, size, handedness, draft, debut, position, experience, and active
status fields.
integer ID (e.g., 3988803); see espn_players() for
reference