Learn R Programming

nhlscraper (version 0.5.0)

espn_team_summary: Access the ESPN summary for a team

Description

espn_team_summary() retrieves the ESPN summary for a team as a data.frame where each row represents one result and includes detail on game timing, matchup state, scoring flow, and situational event detail.

Usage

espn_team_summary(team = 1)

Value

data.frame with one row

Arguments

team

integer ID (e.g., 1); see espn_teams() for reference

Examples

Run this code
ESPN_summary_Boston_Bruins <- espn_team_summary(team = 1)

Run the code above in your browser using DataLab