expansion_drafts: Access all the expansion drafts

View source: R/Draft.R

expansion_draftsR Documentation

Access all the expansion drafts

Description

expansion_drafts() returns expansion-draft rule records by season, including the rule text and season identifiers exposed by the records endpoint.

Usage

expansion_drafts()

Value

data.frame with one row per expansion draft

Examples

all_expansion_drafts <- expansion_drafts()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.