Learn R Programming

nhlscraper (version 0.4.2)

flag_is_rebound: Flag if the shot attempt is a rebound attempt or creates a rebound for all the shots in a play-by-play

Description

flag_is_rebound() flags whether a shot attempt is a rebound attempt (i.e., taken within 3 seconds of a prior blocked, missed, or saved attempt with no stoppage in between), and whether a shot attempt creates a rebound under the same definition.

Usage

flag_is_rebound(play_by_play)

Value

data.frame with one row per event (play) and added columns: createdRebound and isRebound

Arguments

play_by_play

data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference