Access the playoff series results for all the franchises by situation
Source:R/Franchise.R
franchise_playoff_situational_results.Rdfranchise_playoff_situational_results() retrieves the playoff series results for all the franchises by situation as a data.frame where each row represents franchise per situation and includes detail on team identity, affiliation, and matchup-side context.