franchise_season_statistics: Access the statistics for all the franchises by season and...

View source: R/Franchise.R

franchise_season_statisticsR Documentation

Access the statistics for all the franchises by season and game type

Description

franchise_season_statistics() returns records-site franchise results by season and game type, including team, standing, record, goals, and points fields.

Usage

franchise_season_statistics()

franchise_season_stats()

Value

data.frame with one row per franchise per season per game type

Examples

# May take >5s, so skip.
franchise_season_stats <- franchise_season_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.