franchise_statistics: Access the all-time statistics for all the franchises by game...

View source: R/Franchise.R

franchise_statisticsR Documentation

Access the all-time statistics for all the franchises by game type

Description

franchise_statistics() returns all-time franchise totals by game type, including games, wins/losses, goals, points, and related aggregate fields.

Usage

franchise_statistics()

franchise_stats()

Value

data.frame with one row per franchise per game type

Examples

franchise_stats <- franchise_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.