game_odds: Access the real-time game odds for a country by partnered...

View source: R/Game.R

game_oddsR Documentation

Access the real-time game odds for a country by partnered bookmaker

Description

game_odds() returns the public partner-game feed for one country, with one row per current game and normalized team, game type, bookmaker, and odds fields when NHL exposes them.

Usage

game_odds(country = "US")

Arguments

country

two-letter code (e.g., 'CA'); see countries() for reference

Value

data.frame with one row per game

Examples

game_odds_CA <- game_odds(country = 'CA')

nhlscraper documentation built on June 29, 2026, 1:06 a.m.