Learn R Programming

nhlscraper (version 0.2.0)

get_espn_teams: Get ESPN teams by season

Description

get_espn_teams() retrieves ESPN hyperlinks for each team for a given season; the hyperlinks are formatted in base/seasons/{ESPN Season ID}/coaches/{ESPN Team ID}?query. Access get_seasons() for season reference. May soon be reworked to only return the ESPN Team IDs.

Usage

get_espn_teams(season = get_season_now()$seasonId%%10000)

Value

tibble with one row per team

Arguments

season

integer Season in YYYY

Examples

Run this code
ESPN_teams_20242025 <- get_espn_teams(2025)

Run the code above in your browser using DataLab