Learn R Programming

nhlscraper (version 0.4.2)

get_franchise_vs_franchise: Access the all-time statistics versus other franchises for all the franchises by game type

Description

get_franchise_vs_franchise() is deprecated. Use franchise_versus_franchise() instead.

Usage

get_franchise_vs_franchise()

Arguments

Value

data.frame with one row per franchise per franchise per game type