get_game_story: Get World Showcase (WSC) game-story by game
Description
get_game_story() retrieves WSC-provided information on a game, including but not limited to its type, venue, start time, clock, home and away teams, and TV broadcast(s). Access get_games() for game reference.