get_gc_play_by_play() retrieves GC-provided information on each play for a given game, including but not limited to their ID; type; time of occurrence; winning, losing, blocking, shooting, hitting, hit, scoring, assisting, committed-by, drawn-by, and/or served-by player IDs; and X and Y coordinates. Access get_games() for game reference.