get_goalie_statistics: Access various reports for all the goalies by season or game

View source: R/GoalieOld.R

get_goalie_statisticsR Documentation

Access various reports for all the goalies by season or game

Description

get_goalie_statistics() is defunct. Use goalie_season_report() or goalie_game_report() instead.

Usage

get_goalie_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.