get_series: Access the playoff series for a season and round

View source: R/PlayoffOld.R

get_seriesR Documentation

Access the playoff series for a season and round

Description

get_series() is defunct.

Usage

get_series()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.