get_skater_statistics: Access various reports for all the skaters by season or game

View source: R/SkaterOld.R

get_skater_statisticsR Documentation

Access various reports for all the skaters by season or game

Description

get_skater_statistics() is defunct. Use skater_season_report() or skater_game_report() instead.

Usage

get_skater_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.