Learn R Programming

nhlscraper (version 0.2.0)

get_team_scoreboard: Get team scoreboard as of now

Description

get_team_scoreboard() retrieves information on the current game for a given team, including but not limited to their ID, season, type, start date and time, and home and visiting teams' IDs and scores. Access get_teams() for team reference.

Usage

get_team_scoreboard(team = "BOS")

Value

tibble with one row per game

Arguments

team

string 3-letter Code

Examples

Run this code
FLA_scoreboard_now <- get_team_scoreboard(team='FLA')

Run the code above in your browser using DataLab