get_team_statistics() retrieves information on each team or game for a given set of season, game_types, and report. dates must be given when paired with is_game as the default range will return incomplete data (too wide). Access get_configuration() for what information each combination of report, is_aggregate and is_game can provide. Access get_team_seasons() for season and dates references. Will soon be reworked for easier access.