Access the goalie EDGE statistics leaders for a season and game type
Source:R/GoalieEDGE.R
goalie_edge_leaders.Rdgoalie_edge_leaders() returns the goalie EDGE landing-page leader groups
for one season and game type, such as save percentage, 5-on-5 save
percentage, and shot-location leader blocks.
Arguments
- season
integer in YYYYYYYY (e.g., 20242025); see
goalie_edge_seasons()for reference- game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or 'playoff'/'post'; see
goalie_edge_seasons()for reference; most functions will NOT support pre-season