Access the EDGE shot location statistics for a goalie, season, game type, and category
Source:R/GoalieEDGE.R
goalie_edge_shot_location.Rdgoalie_edge_shot_location() retrieves the EDGE shot location statistics for a goalie, season, game type, and category as a data.frame where each row represents shot location and includes detail on production, workload, efficiency, and result-level performance outcomes plus NHL EDGE style tracking outputs and relative-performance context.
Usage
goalie_edge_shot_location(
player = 8476945,
season = "now",
game_type = "",
category = "details"
)Arguments
- player
integer ID (e.g., 8478406)
- season
integer in YYYYYYYY (e.g., 20242025); see
goalie_edge_seasons()for reference- game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or 'playoff'/'post'; see
goalie_edge_seasons()for reference; most functions will NOT support pre-season- category
character of 'd'/details' or 't'/'totals'