Access the EDGE summary for a goalie, season, and game type
Source:R/GoalieEDGE.R
goalie_edge_summary.Rdgoalie_edge_summary() retrieves the EDGE summary for a goalie, season, and game type as a nested list that separates summary and detail blocks for player identity, role, handedness, and biographical profile plus NHL EDGE style tracking outputs and relative-performance context.
Arguments
- player
integer ID (e.g., 8478406)
- season
integer in YYYYYYYY (e.g., 20242025); see
goalie_edge_seasons()for reference- game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or 'playoff'/'post'; see
goalie_edge_seasons()for reference; most functions will NOT support pre-season