goalie_game_statistics: Access the statistics for all the goalies by game

View source: R/Goalie.R

goalie_game_statisticsR Documentation

Access the statistics for all the goalies by game

Description

goalie_game_statistics() returns records-site goalie stat rows by player and game, including opponent fields and normalized team abbreviations.

Usage

goalie_game_statistics()

goalie_game_stats()

Value

data.frame with one row per goalie per game

Examples

goalie_game_stats <- goalie_game_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.