goalie_leaders: Access the goalie statistics leaders for a season, game type,...

View source: R/Goalie.R

goalie_leadersR Documentation

Access the goalie statistics leaders for a season, game type, and category

Description

goalie_leaders() returns the NHL.com leaders table for one goalie category, season, and game type, with normalized player and team fields.

Usage

goalie_leaders(season = "current", game_type = "", category = "wins")

Arguments

season

integer in YYYYYYYY (e.g., 20242025); see seasons() for reference

game_type

integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or playoff'/'post'; see seasons() for reference; most functions will NOT support pre-season

category

character of 'w'/'wins', 's'/shutouts', 's%'/'sP'/'save %'/'save percentage', or 'gaa'/'goals against average'

Value

data.frame with one row per player

Examples

GAA_leaders_regular_20242025 <- goalie_leaders(
  season    = 20242025,
  game_type = 2,
  category  = 'GAA'
)

nhlscraper documentation built on June 29, 2026, 1:06 a.m.