goalie_regular_statistics: Access the career regular season statistics for all the...

View source: R/Goalie.R

goalie_regular_statisticsR Documentation

Access the career regular season statistics for all the goalies

Description

goalie_regular_statistics() returns records-site regular-season career goalie totals, with one row per goalie.

Usage

goalie_regular_statistics()

goalie_regular_stats()

Value

data.frame with one row per goalie

Examples

goalie_career_regular_statistics <- goalie_regular_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.