goalie_scoring: Access the career scoring statistics for all the goalies

View source: R/Goalie.R

goalie_scoringR Documentation

Access the career scoring statistics for all the goalies

Description

goalie_scoring() returns records-site career scoring totals for goalies, with one row per goalie.

Usage

goalie_scoring()

Value

data.frame with one row per player

Examples

goalie_scoring <- goalie_scoring()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.