| goalie_season_statistics | R Documentation |
goalie_season_statistics() returns records-site goalie stat rows by player,
team, season, and game type, preserving separate rows when a goalie changed
teams.
goalie_season_statistics()
goalie_season_stats()
data.frame with one row per player per season per game type, separated by team if applicable
goalie_season_stats <- goalie_season_statistics()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.