goalie_series_statistics: Access the playoff statistics for all the goalies by series

View source: R/Goalie.R

goalie_series_statisticsR Documentation

Access the playoff statistics for all the goalies by series

Description

goalie_series_statistics() returns records-site playoff goalie totals by player and playoff series.

Usage

goalie_series_statistics()

goalie_series_stats()

Value

data.frame with one row per player per series

Examples

goalie_series_stats <- goalie_series_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.