Learn R Programming

nhlscraper (version 0.5.0)

ig_game_cumulative_expected_goals: Save an Instagram (IG) share-able cumulative expected goals (xG) time-series plot for a game

Description

ig_game_cumulative_expected_goals() saves an IG share-able cumulative xG time-series plot for a given game as a PNG.

Usage

ig_game_cumulative_expected_goals(game = 2023030417, model = 1, save = TRUE)

ig_game_cum_xG(game = 2023030417, model = 1)

Value

NULL

Arguments

game

integer ID (e.g., 2025020275); see games() for reference

model

integer in 1:4 indicating which expected goals model to use; see web documentation for what variables each version considers

save

logical only FALSE for tests

Examples

Run this code
# May take >5s, so skip.
ig_game_cumulative_expected_goals(
  game  = 2023030417, 
  model = 1, 
  save  = FALSE
)

Run the code above in your browser using DataLab