Skip to contents

officials() retrieves all the officials as a data.frame where each row represents official and includes detail on player identity, role, handedness, and biographical profile plus coach/management/officiating identity and assignment history.

Usage

officials()

Value

data.frame with one row per official

Examples

all_officials <- officials()