player_game_log() retrieves the game log for a player, season, and game type as a data.frame where each row represents game and includes detail on game timeline state, period/clock progression, and matchup flow plus production, workload, efficiency, and result-level performance outcomes.
Arguments
- player
integer ID (e.g., 8480039); see
players()for reference- season
integer in YYYYYYYY (e.g., 20242025); see
seasons()for reference- game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or playoff'/'post'; see
seasons()for reference; most functions will NOT support pre-season