| player_summary | R Documentation |
player_summary() returns the public player landing payload for one player,
including bio/team fields, current season stats, career totals, season totals,
awards, and featured media when available.
player_summary(player = 8478402)
player |
integer ID (e.g., 8480039); see |
list with various items
Martin_Necas_summary <- player_summary(player = 8480039)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.