roster: Access the roster for a team, season, and position

View source: R/Team.R

rosterR Documentation

Access the roster for a team, season, and position

Description

roster() returns a team's roster for one season and position group, with one row per player and normalized ID, name, sweater, position, height/weight, birth, and handedness fields when available.

Usage

roster(team = 1, season = "current", position = "forwards")

Arguments

team

integer ID (e.g., 21), character full name (e.g., 'Colorado Avalanche'), OR three-letter code (e.g., 'COL'); see teams() for reference; ID is preferable as there now exists duplicate three-letter codes (i.e., 'UTA' for 'Utah Hockey Club' and 'Utah Mammoth')

season

integer in YYYYYYYY (e.g., 20242025); see seasons() for reference

position

character of 'f'/'forwards', 'd'/'defensemen', or 'g'/'goalies'

Value

data.frame with one row per player

Examples

COL_defensemen_20242025 <- roster(
  team     = 21,
  season   = 20242025,
  position = 'D'
)

nhlscraper documentation built on June 29, 2026, 1:06 a.m.