roster_statistics: Access the roster statistics for a team, season, game type, and position
Description
roster_statistics() scrapes the roster statistics for a given set of
team, season, game_type, and position.
Usage
roster_statistics(
team = 1,
season = "now",
game_type = "",
position = "skaters"
)
roster_stats(team = 1, season = "now", game_type = "", position = "skaters")
Value
data.frame with one row per player
Arguments
team
integer ID (e.g., 21), character full name (e.g., 'Colorado
Avalanche'), OR three-letter code (e.g., 'COL'); see teams() for
reference; ID is preferable as there now exists duplicate three-letter codes
(i.e., 'UTA' for 'Utah Hockey Club' and 'Utah Mammoth')
season
integer in YYYYYYYY (e.g., 20242025); see seasons() for
reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
playoff'/'post'; see seasons() for reference; most functions will NOT
support pre-season