schedule() retrieves the schedule for a date as a data.frame where each row represents game and includes detail on game timing, matchup state, scoring flow, and situational event detail.
Usage
schedule(date = Sys.Date())Arguments
- date
character in 'YYYY-MM-DD' (e.g., '2025-01-01'); see
seasons()for reference