season_now() retrieves the season as of now and returns a scalar integer used as the current-context default in season/game-type dependent wrappers.
season_now() retrieves the season as of now and returns a scalar integer used as the current-context default in season/game-type dependent wrappers.