series_schedule() returns the public schedule for one playoff series, with
one row per game and normalized game, team, score/status, venue, and broadcast
fields.
Usage
series_schedule(season = season_now() - 10001, series = "a")series_schedule() returns the public schedule for one playoff series, with
one row per game and normalized game, team, score/status, venue, and broadcast
fields.
series_schedule(season = season_now() - 10001, series = "a")