skater_edge_skating_distance: Access the EDGE skating distance statistics for a skater, season, game type,
and category
Description
skater_edge_skating_distance() retrieves the EDGE skating distance statistics for a skater, season, game type, and category as a data.frame where each row represents strength state and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and tracking/spatial detail such as location, speed, distance, and zone distribution.
Usage
skater_edge_skating_distance(
player = 8478402,
season = "now",
game_type = "",
category = "details"
)
Value
data.frame with one row per strength state (category = 'details')
or game (category = 'last 10')
Arguments
player
integer ID (e.g., 8480039); see players() for reference
season
integer in YYYYYYYY (e.g., 20242025); see
skater_edge_seasons() for reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
'playoff'/'post'; see skater_edge_seasons() for reference; most functions
will NOT support pre-season