Learn R Programming

nhlscraper (version 0.5.0)

skater_edge_zone_time: Access the EDGE zone time statistics for a skater, season, game type, and category

Description

skater_edge_zone_time() retrieves the EDGE zone time statistics for a skater, season, game type, and category as a data.frame where each row represents strength state and includes detail on NHL EDGE style tracking outputs and relative-performance context.

Usage

skater_edge_zone_time(
  player = 8478402,
  season = "now",
  game_type = "",
  category = "details"
)

Value

data.frame with one row per strength state (category = 'details') or list with six items (category = 'starts')

Arguments

player

integer ID (e.g., 8480039); see players() for reference

season

integer in YYYYYYYY (e.g., 20242025); see skater_edge_seasons() for reference

game_type

integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or 'playoff'/'post'; see skater_edge_seasons() for reference; most functions will NOT support pre-season

category

character of 'd'/'details' or 's'/'starts'

Examples

Run this code
Martin_Necas_starts_regular_20242025 <- skater_edge_zone_time(
  player    = 8480039,
  season    = 20242025,
  game_type = 2,
  category  = 'S'
)

Run the code above in your browser using DataLab