skater_game_report: Access various reports for a season, game type, and category for all
the skaters by game
Description
skater_game_report() retrieves various reports for a season, game type, and category for all the skaters by game as a data.frame where each row represents game per player and includes detail on game timeline state, period/clock progression, and matchup flow, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.
integer in YYYYYYYY (e.g., 20242025); see seasons() for
reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
playoff'/'post'; see seasons() for reference; most functions will NOT
support pre-season
category
character (e.g., 'puckPossessions'); see
skater_report_configurations() for reference
# May take >5s, so skip.possession_skater_game_report_playoff_20212022 <-
skater_game_report(
season = 20212022,
game_type = 3,
category = 'puckPossessions' )