Skip to contents

skater_milestones() retrieves the skaters on milestone watch as a data.frame where each row represents player and includes detail on date/season filtering windows and chronological context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.

Usage

skater_milestones()

Value

data.frame with one row per player

Examples

skater_milestones <- skater_milestones()