skater_playoff_statistics: Access the career playoff statistics for all the skaters

View source: R/Skater.R

skater_playoff_statisticsR Documentation

Access the career playoff statistics for all the skaters

Description

skater_playoff_statistics() returns records-site playoff career scoring totals for skaters, with one row per player.

Usage

skater_playoff_statistics()

skater_playoff_stats()

Value

data.frame with one row per player

Examples

skater_playoff_stats <- skater_playoff_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.