skater_regular_statistics: Access the career regular season statistics for all the...

View source: R/Skater.R

skater_regular_statisticsR Documentation

Access the career regular season statistics for all the skaters

Description

skater_regular_statistics() returns records-site regular-season career scoring totals for skaters, with one row per player.

Usage

skater_regular_statistics()

skater_regular_stats()

Value

data.frame with one row per player

Examples

skater_regular_stats <- skater_regular_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.