Learn R Programming

nhlscraper (version 0.5.0)

skater_report_configurations: Access the configurations for skater reports

Description

skater_report_configurations() retrieves the configurations for skater reports as a nested list that separates summary and detail blocks for production, workload, efficiency, and result-level performance outcomes, situational splits across home/road, strength state, and overtime/shootout states, and configuration catalogs for valid report categories and filters.

Usage

skater_report_configurations()

skater_report_configs()

Arguments

Value

list with various items

Examples

Run this code
skater_report_configs <- skater_report_configurations()

Run the code above in your browser using DataLab