| skater_season_statistics | R Documentation |
skater_season_statistics() returns records-site player stat rows by
player, team, season, and game type, preserving separate rows when a player
changed teams.
skater_season_statistics()
skater_season_stats()
data.frame with one row per player per season per game type, separated by team if applicable
# May take >5s, so skip.
skater_season_stats <- skater_season_statistics()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.