Skip to contents

spotlight_players() retrieves the spotlight players as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.

Usage

spotlight_players()

Value

data.frame with one row per player

Examples

spotlight_players <- spotlight_players()