Skip to contents

standings_rules() retrieves the standings rules by season as a data.frame where each row represents season and includes detail on date/season filtering windows and chronological context.

Usage

standings_rules()

Value

data.frame with one row per season

Examples

standings_rules <- standings_rules()