Learn R Programming

nhlscraper (version 0.4.2)

strip_game_id: Strip the game ID into the season ID, game type ID, and game number for all the events (plays) in a play-by-play

Description

strip_game_id() strips the game ID into season ID, game type ID, and game number for all the events (plays) in a play-by-play.

Usage

strip_game_id(play_by_play)

Value

data.frame with one row per event (play) and added columns: seasonId, gameTypeId, and gameNumber

Arguments

play_by_play

data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference