team_edge_leaders: Access the team EDGE statistics leaders for a season and game...

View source: R/TeamEDGE.R

team_edge_leadersR Documentation

Access the team EDGE statistics leaders for a season and game type

Description

team_edge_leaders() returns the team EDGE landing-page leader groups for one season and game type, such as skating, shot, and zone-time leader blocks.

Usage

team_edge_leaders(season = "now", game_type = "")

Arguments

season

integer in YYYYYYYY (e.g., 20242025); see team_edge_seasons() for reference

game_type

integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or 'playoff'/'post'; see team_edge_seasons() for reference; most functions will NOT support pre-season

Value

list of various items

Examples

team_EDGE_leaders_regular_20242025 <- team_edge_leaders(
  season    = 20242025,
  game_type = 2
)

nhlscraper documentation built on June 29, 2026, 1:06 a.m.