team_game_report: Access various reports for a season, game type, and category for all
the teams by game
Description
team_game_report() retrieves various reports for a season, game type, and category for all the teams by game as a data.frame where each row represents game per team and includes detail on game timeline state, period/clock progression, and matchup flow, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.
integer in YYYYYYYY (e.g., 20242025); see seasons() for
reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
playoff'/'post'; see seasons() for reference; most functions will NOT
support pre-season
category
character (e.g., 'leadingtrailing'); see
team_report_configurations() for reference