Learn R Programming

nhlscraper (version 0.5.0)

team_report_configurations: Access the configurations for team reports

Description

team_report_configurations() retrieves the configurations for team reports as a nested list that separates summary and detail blocks for situational splits across home/road, strength state, and overtime/shootout states plus configuration catalogs for valid report categories and filters.

Usage

team_report_configurations()

team_report_configs()

Arguments

Value

list with various items

Examples

Run this code
team_report_configs <- team_report_configurations()

Run the code above in your browser using DataLab