Access various reports for a season, game type, and category for all the teams by season
Source:R/Team.R
team_season_report.Rdteam_season_report() retrieves various reports for a season, game type, and category for all the teams by season as a data.frame where each row represents team and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.
Usage
team_season_report(
season = season_now(),
game_type = game_type_now(),
category = "summary"
)Arguments
- season
integer in YYYYYYYY (e.g., 20242025); see
seasons()for reference- game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or playoff'/'post'; see
seasons()for reference; most functions will NOT support pre-season- category
character (e.g., 'leadingtrailing'); see
team_report_configurations()for reference