team_season_statistics: Access the statistics for all the teams by season and game...

View source: R/Team.R

team_season_statisticsR Documentation

Access the statistics for all the teams by season and game type

Description

team_season_statistics() returns records-site team totals by team, season, and game type, including win/loss, goal, shot, standings-point, and related season-total fields.

Usage

team_season_statistics()

team_season_stats()

Value

data.frame with one row per team per season per game type

Examples

# May take >5s, so skip.
team_season_statistics <- team_season_statistics()

nhlscraper documentation built on June 29, 2026, 1:06 a.m.