teams() returns the stats API team catalog with one row per franchise-era
team entry and normalized identifiers, full names, and tri-codes.
teams() returns the stats API team catalog with one row per franchise-era
team entry and normalized identifiers, full names, and tri-codes.