powered by
x_game_cumulative_expected_goals() saves an X share-able cumulative xG time-series plot for a given game as a PNG.
x_game_cumulative_expected_goals()
game
x_game_cumulative_expected_goals(game = 2023030417, model = 1, save = TRUE)x_game_cum_xG(game = 2023030417, model = 1)
x_game_cum_xG(game = 2023030417, model = 1)
NULL
integer ID (e.g., 2025020275); see games() for reference
games()
integer in 1:4 indicating which expected goals model to use; see web documentation for what variables each version considers
logical only FALSE for tests
# May take >5s, so skip. x_game_cumulative_expected_goals( game = 2023030417, model = 1, save = FALSE )
Run the code above in your browser using DataLab