Learn R Programming

nhlscraper (version 0.5.0)

attendance: Access the attendance by season and game type

Description

attendance() retrieves the attendance by season and game type as a data.frame where each row represents season and includes detail on date/season filtering windows and chronological context.

Usage

attendance()

Arguments

Value

data.frame with one row per season

Examples

Run this code
all_attendance <- attendance()

Run the code above in your browser using DataLab