Learn R Programming

nhlscraper (version 0.5.0)

award_winners: Access all the award winners/finalists

Description

award_winners() retrieves all the award winners/finalists as a data.frame where each row represents winner/finalist and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.

Usage

award_winners()

Arguments

Value

data.frame with one row per winner/finalist

Examples

Run this code
all_award_winners <- award_winners()

Run the code above in your browser using DataLab