boxscore: Access the boxscore for a game, team, and position
Description
boxscore() retrieves the boxscore for a game, team, and position as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile plus production, workload, efficiency, and result-level performance outcomes.
Usage
boxscore(game = 2023030417, team = "home", position = "forwards")
Value
data.frame with one row per player
Arguments
game
integer ID (e.g., 2025020275); see games() for reference
team
character of 'h'/'home' or 'a'/'away'
position
character of 'f'/'forwards', 'd'/'defensemen', or
'g'/'goalies'