Learn R Programming

nhlscraper (version 0.5.0)

coach_career_statistics: Access the career statistics for all the coaches

Description

coach_career_statistics() retrieves the career statistics for all the coaches as a data.frame where each row represents coach and includes detail on ranking movement, points pace, and division/conference position signals.

Usage

coach_career_statistics()

coach_career_stats()

Arguments

Value

data.frame with one row per coach

Examples

Run this code
coach_career_stats <- coach_career_statistics()

Run the code above in your browser using DataLab