Learn R Programming

nhlscraper (version 0.4.2)

coach_franchise_statistics: Access the statistics for all the coaches by franchise and game type

Description

coach_franchise_statistics() scrapes the statistics for all the coaches by franchise and game type.

Usage

coach_franchise_statistics()

coach_franchise_stats()

Arguments

Value

data.frame with one row per franchise per coach per game type

Examples

Run this code
coach_franchise_stats <- coach_franchise_statistics()

Run the code above in your browser using DataLab