powered by
coach_franchise_statistics() scrapes the statistics for all the coaches by franchise and game type.
coach_franchise_statistics()
coach_franchise_statistics()coach_franchise_stats()
coach_franchise_stats()
data.frame with one row per franchise per coach per game type
coach_franchise_stats <- coach_franchise_statistics()
Run the code above in your browser using DataLab