Learn R Programming

nhlscraper (version 0.5.0)

coaches: Access all the coaches

Description

coaches() retrieves all the coaches as a data.frame where each row represents coach and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.

Usage

coaches()

Arguments

Value

data.frame with one row per coach

Examples

Run this code
all_coaches <- coaches()

Run the code above in your browser using DataLab