powered by
coaches() retrieves all the coaches as a data.frame where each row represents coach and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.
coaches()
data.frame
data.frame with one row per coach
all_coaches <- coaches()
Run the code above in your browser using DataLab