Learn R Programming

nhlscraper (version 0.5.0)

combine_reports: Access the draft combine reports

Description

combine_reports() retrieves the draft combine reports as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile.

Usage

combine_reports()

Arguments

Value

data.frame with one row per player

Examples

Run this code
combine_reports <- combine_reports()

Run the code above in your browser using DataLab