powered by
combine_reports() retrieves the draft combine reports as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile.
combine_reports()
data.frame
data.frame with one row per player
combine_reports <- combine_reports()
Run the code above in your browser using DataLab