powered by
countries() retrieves all the countries as a data.frame where each row represents country and includes detail on reference metadata, regional context, and media availability detail.
countries()
data.frame
data.frame with one row per country
all_countries <- countries()
Run the code above in your browser using DataLab