| .drop_illogical_ordered_events | R Documentation |
.drop_illogical_ordered_events() removes stray boundary rows that can
appear between a period's period-end and the following period's
period-start. In practice, these are most often duplicated 0:00
faceoff/stoppage rows that are still tagged to the previous period even
though the actual opening sequence for the next period follows immediately
after.
.drop_illogical_ordered_events(play_by_play)
play_by_play |
data.frame of play-by-play(s); see |
data.frame with illogically ordered boundary events removed
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.