| .flag_is_rush | R Documentation |
.flag_is_rush() flags whether a shot attempt is a rush attempt, defined as any shot attempt occurring within 4 seconds of a prior event in the neutral or defensive zone with no stoppage in play in between.
.flag_is_rush(play_by_play)
play_by_play |
data.frame of play-by-play(s); see |
data.frame with one row per event (play) and added isRush column
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.