| .require_shift_chart_columns | R Documentation |
.require_shift_chart_columns() errors when a helper is called with a shift
chart missing required public schema columns.
.require_shift_chart_columns(shift_chart, cols, fn_name)
shift_chart |
data.frame shift chart object |
cols |
character vector of required columns |
fn_name |
calling function name used in the error message |
NULL, invisibly, or an error if required columns are missing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.