| .strip_time_period | R Documentation |
.strip_time_period() strips the timestamp and period number into the time elapsed in the period and game for all the events (plays) in a play-by-play.
.strip_time_period(play_by_play)
play_by_play |
data.frame of play-by-play(s); see |
data.frame with one row per event (play) and added columns secondsElapsedInPeriod and secondsElapsedInGame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.