Learn R Programming

nhlscraper (version 0.5.0)

draft_picks: Access all the draft picks

Description

draft_picks() retrieves all the draft picks as a data.frame where each row represents pick and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.

Usage

draft_picks()

Arguments

Value

data.frame with one row per pick

Examples

Run this code
# May take >5s, so skip.
all_draft_picks <- draft_picks()

Run the code above in your browser using DataLab