Learn R Programming

nhlscraper (version 0.5.0)

draft_tracker: Access the real-time draft tracker

Description

draft_tracker() retrieves the real-time draft tracker as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and venue/location geography and regional metadata.

Usage

draft_tracker()

Arguments

Value

data.frame with one row per player

Examples

Run this code
draft_tracker <- draft_tracker()

Run the code above in your browser using DataLab