Learn R Programming

nhlscraper (version 0.5.0)

espn_injuries: Access the real-time ESPN injury reports

Description

espn_injuries() retrieves the real-time ESPN injury reports as a data.frame where each row represents team and includes detail on availability status tracking for injuries or transactions.

Usage

espn_injuries()

Arguments

Value

nested data.frame with one row per team (outer) and player (inner)

Examples

Run this code
ESPN_injuries_now <- espn_injuries()

Run the code above in your browser using DataLab