espn_injuries: Access the real-time ESPN injury reports
Description
espn_injuries() retrieves the real-time ESPN injury reports as a data.frame where each row represents team and includes detail on availability status tracking for injuries or transactions.
Usage
espn_injuries()
Arguments
Value
nested data.frame with one row per team (outer) and player (inner)