Learn R Programming

nhlscraper (version 0.5.0)

expansion_draft_picks: Access all the expansion draft picks

Description

expansion_draft_picks() retrieves all the expansion draft picks as a data.frame where each row represents pick and includes detail on date/season filtering windows and chronological context plus team identity, affiliation, and matchup-side context.

Usage

expansion_draft_picks()

Arguments

Value

data.frame with one row per pick

Examples

Run this code
all_expansion_draft_picks <- expansion_draft_picks()

Run the code above in your browser using DataLab