expansion_drafts() returns expansion-draft rule records by season, including
the rule text and season identifiers exposed by the records endpoint.
expansion_drafts() returns expansion-draft rule records by season, including
the rule text and season identifiers exposed by the records endpoint.