Learn R Programming

nhlscraper (version 0.5.0)

expansion_drafts: Access all the expansion drafts

Description

expansion_drafts() retrieves all the expansion drafts as a data.frame where each row represents expansion draft and includes detail on date/season filtering windows and chronological context plus reference definitions and rules-framework information.

Usage

expansion_drafts()

Arguments

Value

data.frame with one row per expansion draft

Examples

Run this code
all_expansion_drafts <- expansion_drafts()

Run the code above in your browser using DataLab