flag_is_rebound() flags whether a shot attempt is a rebound attempt (i.e., taken within 3 seconds of a prior blocked, missed, or saved attempt with no stoppage in between), and whether a shot attempt creates a rebound under the same definition.
flag_is_rebound(play_by_play)data.frame with one row per event (play) and added columns: createdRebound and isRebound
data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference