Learn R Programming

nhlscraper (version 0.4.2)

franchise_playoff_situational_results: Access the playoff series results for all the franchises by situation

Description

franchise_playoff_situational_results() scrapes the playoff series results for all the franchises by situation.

Usage

franchise_playoff_situational_results()

Arguments

Value

data.frame with one row per franchise per situation

Examples

Run this code
franchise_playoff_situational_results <- 
  franchise_playoff_situational_results()

Run the code above in your browser using DataLab