Skip to contents

franchise_season_statistics() returns records-site franchise results by season and game type, including team, standing, record, goals, and points fields.

Usage

franchise_season_statistics()

franchise_season_stats()

Value

data.frame with one row per franchise per season per game type

Examples

# May take >5s, so skip.
franchise_season_stats <- franchise_season_statistics()