Learn R Programming

nhlscraper (version 0.5.0)

franchise_season_statistics: Access the statistics for all the franchises by season and game type

Description

franchise_season_statistics() retrieves the statistics for all the franchises by season and game type as a data.frame where each row represents franchise per season per game type and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.

Usage

franchise_season_statistics()

franchise_season_stats()

Arguments

Value

data.frame with one row per franchise per season per game type

Examples

Run this code
# May take >5s, so skip.
franchise_season_stats <- franchise_season_statistics()

Run the code above in your browser using DataLab