Learn R Programming

nhlscraper (version 0.4.2)

franchise_season_statistics: Access the statistics for all the franchises by season and game type

Description

franchise_season_statistics() scrapes the statistics for all the franchises by season and game type.

Usage

franchise_season_statistics()

franchise_season_stats()

Arguments

Value

data.frame with one row per franchise per season per game type

Examples

Run this code
# May take >5s, so skip.
franchise_season_stats <- franchise_season_statistics()

Run the code above in your browser using DataLab