powered by
franchise_season_statistics() scrapes the statistics for all the franchises by season and game type.
franchise_season_statistics()
franchise_season_statistics()franchise_season_stats()
franchise_season_stats()
data.frame with one row per franchise per season per game type
# May take >5s, so skip. franchise_season_stats <- franchise_season_statistics()
Run the code above in your browser using DataLab