Learn R Programming

nhlscraper (version 0.4.2)

franchise_statistics: Access the all-time statistics for all the franchises by game type

Description

franchise_statistics() scrapes the all-time statistics for all the franchises by game type.

Usage

franchise_statistics()

franchise_stats()

Arguments

Value

data.frame with one row per franchise per game type

Examples

Run this code
franchise_stats <- franchise_statistics()

Run the code above in your browser using DataLab