powered by
franchise_statistics() scrapes the all-time statistics for all the franchises by game type.
franchise_statistics()
franchise_statistics()franchise_stats()
franchise_stats()
data.frame with one row per franchise per game type
franchise_stats <- franchise_statistics()
Run the code above in your browser using DataLab