| franchise_team_statistics | R Documentation |
franchise_team_statistics() returns all-time totals by franchise-era team
and game type, preserving separate rows for teams that share a franchise.
franchise_team_statistics()
franchise_team_stats()
data.frame with one row per team per franchise per game type
franchise_team_stats <- franchise_team_statistics()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.