Learn R Programming

nhlscraper (version 0.5.0)

franchise_team_statistics: Access the all-time statistics for all the franchises by team and game type

Description

franchise_team_statistics() retrieves the all-time statistics for all the franchises by team and game type as a data.frame where each row represents team per franchise per game type and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.

Usage

franchise_team_statistics()

franchise_team_stats()

Arguments

Value

data.frame with one row per team per franchise per game type

Examples

Run this code
franchise_team_stats <- franchise_team_statistics()

Run the code above in your browser using DataLab