Learn R Programming

nhlscraper (version 0.4.2)

franchise_team_statistics: Access the all-time statistics for all the franchises by team and game type

Description

franchise_team_statistics() scrapes the all-time statistics for all the franchises by team and game type.

Usage

franchise_team_statistics()

franchise_team_stats()

Arguments

Value

data.frame with one row per team per franchise per game type

Examples

Run this code
franchise_team_stats <- franchise_team_statistics()

Run the code above in your browser using DataLab