powered by
franchise_team_statistics() scrapes the all-time statistics for all the franchises by team and game type.
franchise_team_statistics()
franchise_team_statistics()franchise_team_stats()
franchise_team_stats()
data.frame with one row per team per franchise per game type
franchise_team_stats <- franchise_team_statistics()
Run the code above in your browser using DataLab