Access the all-time statistics versus other franchises for all the franchises by game type
Source:R/Franchise.R
franchise_versus_franchise.Rdfranchise_versus_franchise() retrieves the all-time statistics versus other franchises for all the franchises by game type as a data.frame where each row represents franchise per franchise per game type and includes detail on date/season filtering windows and chronological context plus team identity, affiliation, and matchup-side context.