Learn R Programming

nhlscraper (version 0.4.2)

franchise_versus_franchise: Access the all-time statistics versus other franchises for all the franchises by game type

Description

franchise_versus_franchise() scrapes the all-time statistics versus other franchises for all the franchises by game type.

Usage

franchise_versus_franchise()

franchise_vs_franchise()

Arguments

Value

data.frame with one row per franchise per franchise per game type

Examples

Run this code
# May take >5s, so skip.
franchise_vs_franchise <- franchise_versus_franchise()

Run the code above in your browser using DataLab