powered by
franchise_versus_franchise() scrapes the all-time statistics versus other franchises for all the franchises by game type.
franchise_versus_franchise()
franchise_versus_franchise()franchise_vs_franchise()
franchise_vs_franchise()
data.frame with one row per franchise per franchise per game type
# May take >5s, so skip. franchise_vs_franchise <- franchise_versus_franchise()
Run the code above in your browser using DataLab