game_odds() retrieves the real-time game odds for a country by partnered bookmaker as a data.frame where each row represents game and includes detail on betting market lines, prices, and provider-level context.
Arguments
- country
two-letter code (e.g., 'CA'); see
countries()for reference