game_rosters() retrieves the rosters for a game as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.
Arguments
- game
integer ID (e.g., 2025020275); see
games()for reference