Learn R Programming

nhlscraper (version 0.5.0)

game_rosters: Access the rosters for a game

Description

game_rosters() retrieves the rosters for a game as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.

Usage

game_rosters(game = 2023030417)

Value

data.frame with one row per player

Arguments

game

integer ID (e.g., 2025020275); see games() for reference

Examples

Run this code
rosters_Martin_Necas_legacy_game <- game_rosters(game = 2025020275)

Run the code above in your browser using DataLab