Learn R Programming

nhlscraper (version 0.5.0)

gc_play_by_play: Access the GameCenter (GC) play-by-play for a game

Description

gc_play_by_play() retrieves the GameCenter (GC) play-by-play for a game as a data.frame where each row represents event and includes detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and player identity, role, handedness, and biographical profile.

Usage

gc_play_by_play(game = 2023030417)

gc_pbp(game = 2023030417)

Value

data.frame with one row per event (play)

Arguments

game

integer ID (e.g., 2025020275); see games() for reference

Examples

Run this code
gc_pbp_Martin_Necas_legacy_game <- gc_play_by_play(game = 2025020275)

Run the code above in your browser using DataLab