get_franchise_season_by_season: Access the statistics for all the franchises by season and game type
Description
get_franchise_season_by_season() is deprecated. Use
franchise_season_statistics() instead.
Usage
get_franchise_season_by_season()
Value
data.frame with one row per franchise per season per game type