get_franchise_team_totals: Access the all-time statistics for all the franchises by team and game type
Description
get_franchise_team_totals() is deprecated. Use
franchise_team_statistics() instead.
Usage
get_franchise_team_totals()
Value
data.frame with one row per team per franchise per game type