get_team_scoreboard: Get team scoreboard as of now
Description
get_team_scoreboard() retrieves information on the current game for a given team, including but not limited to their ID, season, type, start date and time, and home and visiting teams' IDs and scores. Access get_teams() for team reference.