Learn R Programming

nhlscraper (version 0.5.0)

goalie_game_scoring: Access the scoring statistics for all the goalies by game

Description

goalie_game_scoring() retrieves the scoring statistics for all the goalies by game as a data.frame with detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and team identity, affiliation, and matchup-side context.

Usage

goalie_game_scoring()

Arguments

Value

data.frame with one row per player per game

Examples

Run this code
goalie_game_scoring <- goalie_game_scoring()

Run the code above in your browser using DataLab