Learn R Programming

nhlscraper (version 0.4.2)

goalie_game_scoring: Access the scoring statistics for all the goalies by game

Description

goalie_game_scoring() scrapes the scoring statistics for all the goalies by game.

Usage

goalie_game_scoring()

Arguments

Value

data.frame with one row per player per game

Examples

Run this code
goalie_game_scoring <- goalie_game_scoring()

Run the code above in your browser using DataLab