Learn R Programming

nhlscraper (version 0.5.0)

goalie_game_statistics: Access the statistics for all the goalies by game

Description

goalie_game_statistics() retrieves the statistics for all the goalies by game as a data.frame with detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and team identity, affiliation, and matchup-side context.

Usage

goalie_game_statistics()

goalie_game_stats()

Arguments

Value

data.frame with one row per goalie per game

Examples

Run this code
goalie_game_stats <- goalie_game_statistics()

Run the code above in your browser using DataLab