Learn R Programming

nhlscraper (version 0.4.2)

goalie_game_statistics: Access the statistics for all the goalies by game

Description

goalie_game_statistics() scrapes the statistics for all the goalies by game.

Usage

goalie_game_statistics()

goalie_game_stats()

Arguments

Value

data.frame with one row per goalie per game

Examples

Run this code
goalie_game_stats <- goalie_game_statistics()

Run the code above in your browser using DataLab