Learn R Programming

nhlscraper (version 0.5.0)

goalie_milestones: Access the goalies on milestone watch

Description

goalie_milestones() retrieves the goalies on milestone watch as a data.frame where each row represents player and includes detail on date/season filtering windows and chronological context, player identity, role, handedness, and biographical profile, and ranking movement, points pace, and division/conference position signals.

Usage

goalie_milestones()

Arguments

Value

data.frame with one row per player

Examples

Run this code
goalie_milestones <- goalie_milestones()

Run the code above in your browser using DataLab