Learn R Programming

nhlscraper (version 0.5.0)

goalie_regular_statistics: Access the career regular season statistics for all the goalies

Description

goalie_regular_statistics() retrieves the career regular season statistics for all the goalies as a data.frame where each row represents goalie and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.

Usage

goalie_regular_statistics()

goalie_regular_stats()

Arguments

Value

data.frame with one row per goalie

Examples

Run this code
goalie_career_regular_statistics <- goalie_regular_statistics()

Run the code above in your browser using DataLab