Learn R Programming

nhlscraper (version 0.4.2)

goalie_regular_statistics: Access the career regular season statistics for all the goalies

Description

goalie_regular_statistics() scrapes the career regular season statistics for all the goalies.

Usage

goalie_regular_statistics()

goalie_regular_stats()

Arguments

Value

data.frame with one row per goalie

Examples

Run this code
goalie_career_regular_statistics <- goalie_regular_statistics()

Run the code above in your browser using DataLab