Learn R Programming

nhlscraper (version 0.5.0)

goalie_scoring: Access the career scoring statistics for all the goalies

Description

goalie_scoring() retrieves the career scoring statistics for all the goalies as a data.frame where each row represents player and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.

Usage

goalie_scoring()

Arguments

Value

data.frame with one row per player

Examples

Run this code
goalie_scoring <- goalie_scoring()

Run the code above in your browser using DataLab