Learn R Programming

nhlscraper (version 0.4.2)

goalie_scoring: Access the career scoring statistics for all the goalies

Description

goalie_scoring() scrapes the career scoring statistics for all the goalies.

Usage

goalie_scoring()

Arguments

Value

data.frame with one row per player

Examples

Run this code
goalie_scoring <- goalie_scoring()

Run the code above in your browser using DataLab