Access the statistics for all the goalies by season, game type, and team.
Source:R/Goalie.R
goalie_season_statistics.Rdgoalie_season_statistics() returns records-site goalie stat rows by player,
team, season, and game type, preserving separate rows when a goalie changed
teams.