Learn R Programming

nhlscraper (version 0.4.2)

goalie_season_statistics: Access the statistics for all the goalies by season, game type, and team.

Description

goalie_season_statistics() scrapes the statistics for all the goalies by season, game type, and team.

Usage

goalie_season_statistics()

goalie_season_stats()

Arguments

Value

data.frame with one row per player per season per game type, separated by team if applicable

Examples

Run this code
goalie_season_stats <- goalie_season_statistics()

Run the code above in your browser using DataLab