powered by
goalie_season_statistics() scrapes the statistics for all the goalies by season, game type, and team.
goalie_season_statistics()
goalie_season_statistics()goalie_season_stats()
goalie_season_stats()
data.frame with one row per player per season per game type, separated by team if applicable
goalie_season_stats <- goalie_season_statistics()
Run the code above in your browser using DataLab