Access the playoff statistics for all the goalies by series
Source:R/Goalie.R
goalie_series_statistics.Rdgoalie_series_statistics() retrieves the playoff statistics for all the goalies by series as a data.frame where each row represents player per series and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.