Learn R Programming

nhlscraper (version 0.5.0)

goalie_series_statistics: Access the playoff statistics for all the goalies by series

Description

goalie_series_statistics() retrieves the playoff statistics for all the goalies by series as a data.frame where each row represents player per series and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.

Usage

goalie_series_statistics()

goalie_series_stats()

Arguments

Value

data.frame with one row per player per series

Examples

Run this code
goalie_series_stats <- goalie_series_statistics()

Run the code above in your browser using DataLab