Learn R Programming

nhlscraper (version 0.4.2)

goalie_series_statistics: Access the playoff statistics for all the goalies by series

Description

goalie_series_statistics() scrapes the playoff statistics for all the goalies by series.

Usage

goalie_series_statistics()

goalie_series_stats()

Arguments

Value

data.frame with one row per player per series

Examples

Run this code
goalie_series_stats <- goalie_series_statistics()

Run the code above in your browser using DataLab