Learn R Programming

nhlscraper (version 0.5.0)

goalie_statistics: Access the career statistics for all the goalies

Description

goalie_statistics() retrieves the career statistics for all the goalies as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.

Usage

goalie_statistics()

goalie_stats()

Arguments

Value

data.frame with one row per player

Examples

Run this code
goalie_stats <- goalie_statistics()

Run the code above in your browser using DataLab