location() retrieves the location for a zip code as a data.frame where each row represents team and includes detail on venue/location geography and regional metadata.
location() retrieves the location for a zip code as a data.frame where each row represents team and includes detail on venue/location geography and regional metadata.