Learn R Programming

nhlscraper (version 0.5.0)

location: Access the location for a zip code

Description

location() retrieves the location for a zip code as a data.frame where each row represents team and includes detail on venue/location geography and regional metadata.

Usage

location(zip = 10001)

Value

data.frame with one row per team

Arguments

zip

integer (e.g., 48304)

Examples

Run this code
Cranbrook_Schools <- location(48304)

Run the code above in your browser using DataLab