powered by
location() retrieves the location for a zip code as a data.frame where each row represents team and includes detail on venue/location geography and regional metadata.
location()
data.frame
location(zip = 10001)
data.frame with one row per team
integer (e.g., 48304)
Cranbrook_Schools <- location(48304)
Run the code above in your browser using DataLab