Learn R Programming

nhlscraper (version 0.5.0)

officials: Access all the officials

Description

officials() retrieves all the officials as a data.frame where each row represents official and includes detail on player identity, role, handedness, and biographical profile plus coach/management/officiating identity and assignment history.

Usage

officials()

Arguments

Value

data.frame with one row per official

Examples

Run this code
all_officials <- officials()

Run the code above in your browser using DataLab