powered by
officials() retrieves all the officials as a data.frame where each row represents official and includes detail on player identity, role, handedness, and biographical profile plus coach/management/officiating identity and assignment history.
officials()
data.frame
data.frame with one row per official
all_officials <- officials()
Run the code above in your browser using DataLab