player_game_log: Access the game log for a player, season, and game type
Description
player_game_log() scrapes the game log for a given set of player,
season, and game_type.
Usage
player_game_log(player = 8478402, season = "now", game_type = "")
Value
data.frame with one row per game
Arguments
player
integer ID (e.g., 8480039); see players() for reference
season
integer in YYYYYYYY (e.g., 20242025); see seasons() for
reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
playoff'/'post'; see seasons() for reference; most functions will NOT
support pre-season