player_summary() retrieves the summary for a player as a nested list that separates summary and detail blocks for player identity, role, handedness, and biographical profile.
Arguments
- player
integer ID (e.g., 8480039); see
players()for reference