Learn R Programming

nhlscraper (version 0.5.0)

player_summary: Access the summary for a player

Description

player_summary() retrieves the summary for a player as a nested list that separates summary and detail blocks for player identity, role, handedness, and biographical profile.

Usage

player_summary(player = 8478402)

Value

list with various items

Arguments

player

integer ID (e.g., 8480039); see players() for reference

Examples

Run this code
Martin_Necas_summary <- player_summary(player = 8480039)

Run the code above in your browser using DataLab