player_summary() retrieves the summary for a player as a nested list that separates summary and detail blocks for player identity, role, handedness, and biographical profile.
Usage
player_summary(player = 8478402)
Value
list with various items
Arguments
player
integer ID (e.g., 8480039); see players() for reference