powered by
players() retrieves all the players as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile.
players()
data.frame
data.frame with one row per player
# May take >5s, so skip. all_players <- players()
Run the code above in your browser using DataLab