Learn R Programming

nhlscraper (version 0.5.0)

playoff_season_statistics: Access the playoff statistics by season

Description

playoff_season_statistics() retrieves the playoff statistics by season as a data.frame where each row represents season and includes detail on date/season filtering windows and chronological context.

Usage

playoff_season_statistics()

playoff_season_stats()

Arguments

Value

data.frame with one row per season

Examples

Run this code
playoff_season_stats <- playoff_season_statistics()

Run the code above in your browser using DataLab