replay() retrieves the replay for an event as a data.frame where each row represents decisecond and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.
Arguments
- game
integer ID (e.g., 2025020262); see
games()for reference- event
integer ID (e.g., 751); see
gc_play_by_play()and/orwsc_play_by_play()for reference; must be a 'goal' event