scores() retrieves the scores for a date as a data.frame where each row represents game and includes detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and team identity, affiliation, and matchup-side context.
Arguments
- date
character in 'YYYY-MM-DD' (e.g., '2025-01-01'); see
seasons()for reference