Learn R Programming

nhlscraper (version 0.5.0)

scores: Access the scores for a date

Description

scores() retrieves the scores for a date as a data.frame where each row represents game and includes detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and team identity, affiliation, and matchup-side context.

Usage

scores(date = "now")

Value

data.frame with one row per game

Arguments

date

character in 'YYYY-MM-DD' (e.g., '2025-01-01'); see seasons() for reference

Examples

Run this code
scores_Halloween_2025 <- scores(date = '2025-10-31')

Run the code above in your browser using DataLab