Learn R Programming

nhlscraper (version 0.5.0)

series: Access all the playoff series by game

Description

series() retrieves all the playoff series by game as a data.frame where each row represents game per series and includes detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and playoff-series progression, round status, and series leverage.

Usage

series()

Arguments

Value

data.frame with one row per game per series

Examples

Run this code
# May take >5s, so skip.
all_series <- series()

Run the code above in your browser using DataLab