skater_edge_summary: Access the EDGE summary for a skater, season, and game type
Description
skater_edge_summary() retrieves the EDGE summary for a skater, season, and game type as a nested list that separates summary and detail blocks for player identity, role, handedness, and biographical profile plus NHL EDGE style tracking outputs and relative-performance context.
Usage
skater_edge_summary(player = 8478402, season = "now", game_type = "")
Value
list of various items
Arguments
player
integer ID (e.g., 8480039); see players() for reference
season
integer in YYYYYYYY (e.g., 20242025); see
skater_edge_seasons() for reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
'playoff'/'post'; see skater_edge_seasons() for reference; most functions
will NOT support pre-season