Learn R Programming

nhlscraper (version 0.5.0)

skater_milestones: Access the skaters on milestone watch

Description

skater_milestones() retrieves the skaters on milestone watch as a data.frame where each row represents player and includes detail on date/season filtering windows and chronological context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.

Usage

skater_milestones()

Arguments

Value

data.frame with one row per player

Examples

Run this code
skater_milestones <- skater_milestones()

Run the code above in your browser using DataLab