Learn R Programming

nhlscraper (version 0.5.0)

skater_playoff_statistics: Access the career playoff statistics for all the skaters

Description

skater_playoff_statistics() retrieves the career playoff statistics for all the skaters as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.

Usage

skater_playoff_statistics()

skater_playoff_stats()

Arguments

Value

data.frame with one row per player

Examples

Run this code
skater_playoff_stats <- skater_playoff_statistics()

Run the code above in your browser using DataLab