Learn R Programming

nhlscraper (version 0.4.2)

skater_playoff_statistics: Access the career playoff statistics for all the skaters

Description

skater_playoff_statistics() scrapes the career playoff statistics for all the skaters.

Usage

skater_playoff_statistics()

skater_playoff_stats()

Arguments

Value

data.frame with one row per player

Examples

Run this code
skater_playoff_stats <- skater_playoff_statistics()

Run the code above in your browser using DataLab