Access the career regular season statistics for all the skaters
Source:R/Skater.R
skater_regular_statistics.Rdskater_regular_statistics() returns records-site regular-season career
scoring totals for skaters, with one row per player.

R/Skater.R
skater_regular_statistics.Rdskater_regular_statistics() returns records-site regular-season career
scoring totals for skaters, with one row per player.