Learn R Programming

nhlscraper (version 0.5.0)

skater_regular_statistics: Access the career regular season statistics for all the skaters

Description

skater_regular_statistics() retrieves the career regular season statistics for all the skaters as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context, player identity, role, handedness, and biographical profile, and production, workload, efficiency, and result-level performance outcomes.

Usage

skater_regular_statistics()

skater_regular_stats()

Arguments

Value

data.frame with one row per player

Examples

Run this code
skater_regular_stats <- skater_regular_statistics()

Run the code above in your browser using DataLab