Learn R Programming

nhlscraper (version 0.4.2)

skater_regular_statistics: Access the career regular season statistics for all the skaters

Description

skater_regular_statistics() scrapes the career regular season statistics for all the skaters.

Usage

skater_regular_statistics()

skater_regular_stats()

Arguments

Value

data.frame with one row per player

Examples

Run this code
skater_regular_stats <- skater_regular_statistics()

Run the code above in your browser using DataLab