Learn R Programming

nhlscraper (version 0.4.2)

skater_season_statistics: Access the statistics for all the skaters by season, game type, and team

Description

skater_season_statistics() scrapes the statistics for all the skaters by season, game type, and team.

Usage

skater_season_statistics()

skater_season_stats()

Arguments

Value

data.frame with one row per player per season per game type, separated by team if applicable

Examples

Run this code
# May take >5s, so skip.
skater_season_stats <- skater_season_statistics()

Run the code above in your browser using DataLab