Learn R Programming

nhlscraper (version 0.5.0)

skater_series_statistics: Access the playoff statistics for all the skaters by series

Description

skater_series_statistics() retrieves the playoff statistics for all the skaters by series as a data.frame where each row represents player per series and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and player identity, role, handedness, and biographical profile.

Usage

skater_series_statistics()

skater_series_stats()

Arguments

Value

data.frame with one row per player per series

Examples

Run this code
# May take >5s, so skip.
skater_series_stats <- skater_series_statistics()

Run the code above in your browser using DataLab