Learn R Programming

nhlscraper (version 0.5.0)

skater_statistics: Access the career statistics for all the skaters

Description

skater_statistics() retrieves the career statistics for all the skaters as a data.frame where each row represents player and includes detail on player identity, role, handedness, and biographical profile plus production, workload, efficiency, and result-level performance outcomes.

Usage

skater_statistics()

skater_stats()

Arguments

Value

data.frame with one row per player

Examples

Run this code
skater_stats <- skater_statistics()

Run the code above in your browser using DataLab