Learn R Programming

nhlscraper (version 0.5.0)

spotlight_players: Access the spotlight players

Description

spotlight_players() retrieves the spotlight players as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.

Usage

spotlight_players()

Arguments

Value

data.frame with one row per player

Examples

Run this code
spotlight_players <- spotlight_players()

Run the code above in your browser using DataLab