powered by
spotlight_players() retrieves the spotlight players as a data.frame where each row represents player and includes detail on team identity, affiliation, and matchup-side context plus player identity, role, handedness, and biographical profile.
spotlight_players()
data.frame
data.frame with one row per player
spotlight_players <- spotlight_players()
Run the code above in your browser using DataLab