standings() retrieves the standings for a date as a data.frame where each row represents team and includes detail on date/season filtering windows and chronological context, production, workload, efficiency, and result-level performance outcomes, and ranking movement, points pace, and division/conference position signals.
Arguments
- date
character in 'YYYY-MM-DD' (e.g., '2025-01-01'); see
seasons()for reference