Learn R Programming

nhlscraper (version 0.5.0)

standings_rules: Access the standings rules by season

Description

standings_rules() retrieves the standings rules by season as a data.frame where each row represents season and includes detail on date/season filtering windows and chronological context.

Usage

standings_rules()

Arguments

Value

data.frame with one row per season

Examples

Run this code
standings_rules <- standings_rules()

Run the code above in your browser using DataLab