strip_time_period() strips the timestamp and period number into the time elapsed in the period and game for all the events (plays) in a play-by-play.
strip_time_period(play_by_play)data.frame with one row per event (play) and added columns secondsElapsedInPeriod and secondsElapsedInGame
data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference