Learn R Programming

nhlscraper (version 0.4.1)

strip_time_period: Strip the timestamp and period number into the time elapsed in the period and game for all the events (plays) in a play-by-play

Description

strip_time_period() strip the timestamp and period number into the time elapsed in the period and game for all the events (plays) in a play-by-play.

Usage

strip_time_period(play_by_play)

Value

data.frame with one row per event (play) and added columns secondsElapsedInPeriod and secondsElapsedInGame

Arguments

play_by_play

data.frame of play-by-play(s); see gc_play_by_play() and/or wsc_play_by_play() for reference; must be untouched by non-nhlscraper functions; saves time if strip_game_id() has already been called

Examples

Run this code
# May take >5s, so skip.
# \donttest{
  test                      <- gc_play_by_play()
  test_game_id_stripped     <- strip_game_id(test)
  test_time_period_stripped <- strip_time_period(test_game_id_stripped)
# }

Run the code above in your browser using DataLab