Learn R Programming

nhlscraper (version 0.4.2)

team_edge_leaders: Access the team EDGE statistics leaders for a season and game type

Description

team_edge_leaders() scrapes the team EDGE statistics leaders for a given set of season and game_type.

Usage

team_edge_leaders(season = "now", game_type = "")

Value

list of various items

Arguments

season

integer in YYYYYYYY (e.g., 20242025); see team_edge_seasons() for reference

game_type

integer in 1:3 (where 1 = pre-season, 2 = regular season, 3 = playoff/post-season) OR character of 'pre', 'regular', or 'playoff'/'post'; see team_edge_seasons() for reference; most functions will NOT support pre-season

Examples

Run this code
team_EDGE_leaders_regular_20242025 <- team_edge_leaders(
  season    = 20242025,
  game_type = 2
)

Run the code above in your browser using DataLab