team_edge_skating_distance: Access the EDGE skating distance statistics for a team, season, game type,
and category
Description
team_edge_skating_distance() scrapes the EDGE skating distance
statistics for a given set of team, season, game_type, and
category.
Usage
team_edge_skating_distance(
team = 1,
season = "now",
game_type = "",
category = "details"
)
Value
data.frame with one row per combination of strength state and
position (category = 'details') or game (category = 'last 10')
game
Arguments
team
integer ID (e.g., 21), character full name (e.g., 'Colorado
Avalanche'), OR three-letter code (e.g., 'COL'); see teams() for
reference; ID is preferable as there now exists duplicate three-letter codes
(i.e., 'UTA' for 'Utah Hockey Club' and 'Utah Mammoth')
season
integer in YYYYYYYY (e.g., 20242025); see
team_edge_seasons() for reference
game_type
integer in 1:3 (where 1 = pre-season, 2 = regular season, 3
= playoff/post-season) OR character of 'pre', 'regular', or
'playoff'/'post'; see team_edge_seasons() for reference; most functions
will NOT support pre-season