team_month_schedule: Access the schedule for a team and month
Description
team_month_schedule() scrapes the schedule for a given set of team
and month.
Usage
team_month_schedule(team = 1, month = "now")
Value
data.frame with one row per game
Arguments
team
integer ID (e.g., 21), character full name (e.g., 'Colorado
Avalanche'), OR three-letter code (e.g., 'COL'); see teams() for
reference; ID is preferable as there now exists duplicate three-letter codes
(i.e., 'UTA' for 'Utah Hockey Club' and 'Utah Mammoth')
month
character in 'YYYY-MM' (e.g., '2025-01'); see seasons()
for reference