team_season_schedule: Access the schedule for a team and season
Description
team_season_schedule() scrapes the schedule for a given set of team
and season.
Usage
team_season_schedule(team = 1, season = "now")
Value
data.frame with one row per game
Arguments
team
integer ID (e.g., 21), character full name (e.g., 'Colorado
Avalanche'), OR three-letter code (e.g., 'COL'); see teams() for
reference; ID is preferable as there now exists duplicate three-letter codes
(i.e., 'UTA' for 'Utah Hockey Club' and 'Utah Mammoth')
season
integer in YYYYYYYY (e.g., 20242025); see seasons() for
reference