Learn R Programming

nhlscraper (version 0.5.0)

team_season_statistics: Access the statistics for all the teams by season and game type

Description

team_season_statistics() retrieves the statistics for all the teams by season and game type as a data.frame where each row represents team per season per game type and includes detail on date/season filtering windows and chronological context, team identity, affiliation, and matchup-side context, and production, workload, efficiency, and result-level performance outcomes.

Usage

team_season_statistics()

team_season_stats()

Arguments

Value

data.frame with one row per team per season per game type

Examples

Run this code
# May take >5s, so skip.
team_season_statistics <- team_season_statistics()

Run the code above in your browser using DataLab