Learn R Programming

nhlscraper (version 0.4.2)

team_season_statistics: Access the statistics for all the teams by season and game type

Description

team_season_statistics() scrapes the statistics for all the teams by season and game type.

Usage

team_season_statistics()

team_season_stats()

Arguments

Value

data.frame with one row per team per season per game type

Examples

Run this code
# May take >5s, so skip.
team_season_statistics <- team_season_statistics()

Run the code above in your browser using DataLab