powered by
team_season_statistics() scrapes the statistics for all the teams by season and game type.
team_season_statistics()
team_season_statistics()team_season_stats()
team_season_stats()
data.frame with one row per team per season per game type
# May take >5s, so skip. team_season_statistics <- team_season_statistics()
Run the code above in your browser using DataLab