Learn R Programming

nhlscraper (version 0.5.0)

wsc_play_by_play: Access the World Showcase (WSC) play-by-play for a game

Description

wsc_play_by_play() retrieves the World Showcase (WSC) play-by-play for a game as a data.frame where each row represents event and includes detail on game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and player identity, role, handedness, and biographical profile.

Usage

wsc_play_by_play(game = 2023030417)

wsc_pbp(game = 2023030417)

Value

data.frame with one row per event (play)

Arguments

game

integer ID (e.g., 2025020275); see games() for reference

Examples

Run this code
wsc_pbp_Martin_Necas_legacy_game <- wsc_play_by_play(game = 2025020275)

Run the code above in your browser using DataLab