Learn R Programming

nhlscraper (version 0.5.0)

wsc_summary: Access the World Showcase (WSC) summary for a game

Description

wsc_summary() retrieves the World Showcase (WSC) summary for a game as a nested list that separates summary and detail blocks for game timeline state, period/clock progression, and matchup flow, date/season filtering windows and chronological context, and venue/location geography and regional metadata.

Usage

wsc_summary(game = 2023030417)

Value

list of various items

Arguments

game

integer ID (e.g., 2025020275); see games() for reference

Examples

Run this code
wsc_summary_Martin_Necas_legacy_game <- wsc_summary(game = 2025020275)

Run the code above in your browser using DataLab